<div align="center">
<h1 align="center">GenAI Agents </h1>

<a href="https://img.shields.io/badge/Python-3.11+-3776AB.svg?style=flat&logo=python&logoColor=white"><img src="https://img.shields.io/badge/Python-3.11+-3776AB.svg?style=flat&logo=python&logoColor=white" alt="Python 3.11+"></a>

</div>

## Installation

1. Setup a virtual environment.

   #### Note: Use python3.11

   ```bash
   python3 -m venv venv
   source venv/bin/activate
   ```

2. Install the genai-agents

   ```bash
   pip install -U genai-agents
   ```

## Documentations

The documentation for GenAI Agents can be found at [agents.genaistack.aiplanet.com](https://agents.genaistack.aiplanet.com/)

## Get in Touch

You can schedule a 1:1 meeting with our DevRel & Community Team to get started with AI Planet Open Source LLMs(effi and Panda Coder), GenAI Stack and GenAI Agents. Schedule the call here: [https://calendly.com/jaintarun](https://calendly.com/jaintarun)

## Contribution guidelines

GenAI Stack thrives in the rapidly evolving landscape of open-source projects. We wholeheartedly welcome contributions in various capacities, be it through innovative features, enhanced infrastructure, or refined documentation.
